@@ -3,7 +3,7 @@ package DBIx::Class::UUIDColumns::UUIDMaker::Win32API::GUID;
 use strict;
 use warnings;
 
-use base qw/DBIx::Class::UUIDMaker/;
+use base qw/DBIx::Class::UUIDColumns::UUIDMaker/;
 use Win32API::GUID ();
 
 sub as_string {
